@@ -1,11 +1,6 @@
-from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
-from builtins import object
 from datetime import datetime
 import json
 import logging
-import six
 
 import pytest
 
@@ -234,13 +229,9 @@ class TestDataJSONHarvester(object):
 
         pytest.raises(URLError)
         assert self.job.gather_errors[0].message == "HTTP Error getting json source: HTTP Error 404: Not Found."
-        if six.PY2:
-            assert self.job.gather_errors[1].message == ("Error loading json content: need more "
-                                                         "than 0 values to unpack.")
-        else:
-            assert self.job.gather_errors[1].message == ("Error loading json content:"
-                                                         " not enough values to unpack"
-                                                         " (expected 2, got 0).")
+        assert self.job.gather_errors[1].message == ("Error loading json content:"
+                                                     " not enough values to unpack"
+                                                     " (expected 2, got 0).")
 
     def test_source_returning_url_error(self):
         # URL failing SSL
@@ -249,13 +240,9 @@ class TestDataJSONHarvester(object):
 
         pytest.raises(URLError)
         assert "URL Error getting json source: <urlopen error" in self.job.gather_errors[0].message
-        if six.PY2:
-            assert self.job.gather_errors[1].message == ("Error loading json content: need more "
-                                                         "than 0 values to unpack.")
-        else:
-            assert self.job.gather_errors[1].message == ("Error loading json content:"
-                                                         " not enough values to unpack"
-                                                         " (expected 2, got 0).")
+        assert self.job.gather_errors[1].message == ("Error loading json content:"
+                                                     " not enough values to unpack"
+                                                     " (expected 2, got 0).")
 
     def get_datasets_from_2_collection(self):
         url = 'http://127.0.0.1:%s/collection-2-parent-4-children.data.json' % self.mock_port
